@@ -283,13 +283,72 @@ def transform_for_multiple_targets_code(content):
                 old_node_content = ast.get_source_segment(content, e[0])
 
                 line_list=[[(e[0].lineno,e[0].col_offset),(e[0].end_lineno,e[0].end_col_offset)]]
-                code_pair_list.append([class_name,me_name,[old_node_content], [ast.unparse(e[1])],line_list])
+
+                new_code_fragment_list=ast.unparse(e[1]).split('\n')
+
+                for ind,e_fragment in enumerate(new_code_fragment_list):
+
+                    if ind>0:
+
+                        new_code_fragment_list[ind]=' '*e[0].col_offset+e_fragment
+
+                print("for multi targets ast.unparse(e[1]): ",ast.unparse(e[1]))
+                # code_pair_list.append([class_name,me_name,[old_node_content], [ast.unparse(e[1])],line_list])
+                code_pair_list.append([class_name,me_name,[old_node_content], ["\n".join(new_code_fragment_list)],line_list])
 
         return code_pair_list
 
     except:
         traceback.print_exc()
         return code_pair_list
+
+def get_for_multi_tar_part_fragment(content):
+    code_pair_list = []
+
+    try:
+
+            tree = ast.parse(content)
+
+            try:
+                me_name = tree.name
+            except:
+                me_name = ""
+            new_code_list = get_for_target(tree)
+
+            # print("new_code_list: ",new_code_list)
+            for e in new_code_list:
+                # print("new_tree: ",ast.unparse(e[0]),ast.unparse(e[1]))
+                if len(e) < 2:
+                    print(">>>>>>>>>>>the code1 I cannot transform: ", e, ast.unparse(e))
+                    continue
+
+                # new_file_content = replace_file_content_ass(content, each_assign_list, new_code)
+                # assign_list[ind_ass].append(new_code)
+                # complic_code_me_info_dir_pkl = util.data_root + "complic_code_me_info_dir_pkl/each_idiom_type_all_methods/multi_ass/"  # for_else
+                # util.save_file(complic_code_me_info_dir_pkl, "test"+str(ind_ass), new_file_content, ".txt", "w")
+                # util.save_file(complic_code_me_info_dir_pkl, "test_old"+str(ind_ass), content, ".txt", "w")
+                if 1:#target_node_str == ast.unparse(e[0]):
+                    print("come for multi targets")
+                    old_node_content = ast.get_source_segment(content, e[0])
+                    line_list=[[(e[0].lineno,e[0].col_offset),(e[0].end_lineno,e[0].end_col_offset)]]
+
+                    new_code_fragment_list=ast.unparse(e[1]).split('\n')
+
+                    for ind,e_fragment in enumerate(new_code_fragment_list):
+
+                        if ind>0:
+
+                            new_code_fragment_list[ind]=' '*e[0].col_offset+e_fragment
+
+
+                    # code_pair_list.append([class_name,me_name,[old_node_content], [ast.unparse(e[1])],line_list])
+                    code_pair_list.append(['',me_name,[old_node_content], ["\n".join(new_code_fragment_list)],line_list])
+
+            return code_pair_list
+
+    except:
+        traceback.print_exc()
+        return code_pair_list
 def save_repo_for_else_complicated(repo_name):
     start=time.time()
     count_complicated_code = 0
