@@ -316,7 +316,7 @@ def file_replace(abs_path, each_file_code_list):
         # print("lines: ",lines)
         # return None
         pre_lineno=None
-        for each_group_code in  group_new_sorted_code_list:
+        for ind_group,each_group_code in  enumerate(group_new_sorted_code_list):
             # print("1. each_group_code: ",each_group_code,len(each_group_code))
             bias=each_group_code[0][0]-1
             code_fragment_list = lines[each_group_code[0][0]-1:each_group_code[0][1]]
@@ -480,6 +480,9 @@ def file_replace(abs_path, each_file_code_list):
                     pre_lineno=max(start_row,pre_lineno[0]), max(end_row,pre_lineno[1])
                 else:
                     pre_lineno=start_row, end_row
+                if ind_each_code==len(each_group_code)-1:
+                    new_content.extend(lines[pre_lineno[1]:])
+
 
 
     return "".join(new_content)
@@ -564,19 +567,26 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='RefactoringIdioms')
     parser.add_argument('--envname', type=str,
                         help='envname', default="CartPole-v0")
-    # parser.add_argument('--filepath', type=str,
-    #                     help='filepath', default=abs_path+"/file.py")
+    parser.add_argument('--filepath', type=str,
+                        help='filepath', default=abs_path+"/file.py")
     # parser.add_argument('--filepath', type=str,
     #                     help='filepath', default=abs_path + "/")
-    parser.add_argument('--filepath', type=str,
-                        help='filepath', default= "./")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default= "./")
+    # parser.add_argument('--filepath', type=str,
+    #                     help='filepath', default="/Users/zhangzejunzhangzejun/PycharmProjects/code")
     #
     parser.add_argument('--idiom', type=str,
                         help='idiom', default="All")
     parser.add_argument('--outputdir', type=str,
                         help='outputdir', default="./RefactoringIdiomsOutputdir/")
+    # parser.add_argument('--outputdir', type=str,
+    #                     help='outputdir', default="/Users/zhangzejunzhangzejun/PycharmProjects/code/RefactoringIdiomsOutputdir/")
+    #
+    # parser.add_argument('--flag_merge_allcodepair', type=str,
+    #                     help='flag_merge_allcodepair', default=1)
     parser.add_argument('--flag_merge_allcodepair', type=str,
-                        help='flag_merge_allcodepair', default=1)
+                        help='flag_merge_allcodepair', default=0)
     parser.add_argument('--output_codepair', type=str,
                         help='output_codepair', default="result.json")
     parser.add_argument('--flag_console_output', type=str,
